---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "vercel_deployment Resource - terraform-provider-vercel"
subcategory: ""
description: |-
  Provides a Deployment resource.
  A Deployment is the result of building your Project and making it available through a live URL.
  When making deployments, the Project will be uploaded and transformed into a production-ready output through the use of a Build Step.
  Once the build step has completed successfully, a new, immutable deployment will be made available at the preview URL. Deployments are retained indefinitely unless deleted manually.
  -> In order to provide files to a deployment, you'll need to use the vercel_file or vercel_project_directory data sources.
---

# vercel_deployment (Resource)

Provides a Deployment resource.

A Deployment is the result of building your Project and making it available through a live URL.

When making deployments, the Project will be uploaded and transformed into a production-ready output through the use of a Build Step.

Once the build step has completed successfully, a new, immutable deployment will be made available at the preview URL. Deployments are retained indefinitely unless deleted manually.

-> In order to provide files to a deployment, you'll need to use the `vercel_file` or `vercel_project_directory` data sources.

## Example Usage

```terraform
data "vercel_project_directory" "example" {
  path = "../ui"
}

resource "vercel_deployment" "example" {
  project_id = "prj_xxxxxxxxxxxx"
  files      = data.vercel_project_directory.example.files
  production = true

  project_settings = {
    output_directory = ".build"
    build_command    = "npm run build && npm run post-build"
    framework        = "create-react-app"
    root_directory   = "../ui"
  }

  environment = {
    FOO = "bar"
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- **files** (Map of String) A map of files to be uploaded for the deployment. This should be provided by a `vercel_project_directory` or `vercel_file` data source.
- **project_id** (String) The project ID to add the deployment to.

### Optional

- **environment** (Map of String) A map of environment variable names to values. These are specific to a Deployment, and can also be configured on the `vercel_project` resource.
- **production** (Boolean) true if the deployment is a production deployment, meaning production aliases will be assigned.
- **project_settings** (Attributes) Project settings that will be applied to the deployment. (see [below for nested schema](#nestedatt--project_settings))
- **team_id** (String) The team ID to add the deployment to.

### Read-Only

- **domains** (List of String) A list of all the domains (default domains, staging domains and production domains) that were assigned upon deployment creation.
- **id** (String) The ID of this resource.
- **url** (String) A unique URL that is automatically generated for a deployment.

<a id="nestedatt--project_settings"></a>
### Nested Schema for `project_settings`

Optional:

- **build_command** (String) The build command for this deployment. If omitted, this value will be taken from the project or automatically detected
- **framework** (String) The framework that is being used for this deployment. If omitted, no framework is selected
- **install_command** (String) The install command for this deployment. If omitted, this value will be taken from the project or automatically detected
- **output_directory** (String) The output directory of the deployment. If omitted, this value will be taken from the project or automatically detected
- **root_directory** (String) The name of a directory or relative path to the source code of your project. When null is used it will default to the project root


